==> micronaut-security-oauth2-2.1.3-sources.jar: io/micronaut/security/oauth2/endpoint/nonce/DefaultNonceFactory.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.security.oauth2.endpoint.nonce;

import io.micronaut.context.annotation.Requires;
import io.micronaut.http.HttpRequest;
import io.micronaut.http.MutableHttpResponse;
import io.micronaut.security.oauth2.endpoint.nonce.persistence.NoncePersistence;

import edu.umd.cs.findbugs.annotations.NonNull;
import javax.inject.Singleton;
import java.util.UUID;

/**
 * Generates a random UUID nonce.
 *
 * @author James Kleeh
 * @since 1.2.0
 */
@Requires(beans = NoncePersistence.class)
@Singleton
public class DefaultNonceFactory implements NonceFactory {

    private final NoncePersistence noncePersistence;

    /**
     * @param noncePersistence The nonce persistence mechanism
     */
    public DefaultNonceFactory(NoncePersistence noncePersistence) {
        this.noncePersistence = noncePersistence;
    }

    @NonNull
    @Override
    public String buildNonce(HttpRequest<?> request, MutableHttpResponse response) {
        String nonce = UUID.randomUUID().toString();
        noncePersistence.persistNonce(request, response, nonce);
        return nonce;
    }
}

==> micronaut-security-oauth2-3.7.1-sources.jar: io/micronaut/security/oauth2/endpoint/nonce/DefaultNonceFactory.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.security.oauth2.endpoint.nonce;

import io.micronaut.context.annotation.Requires;
import io.micronaut.core.annotation.NonNull;
import io.micronaut.http.HttpRequest;
import io.micronaut.http.MutableHttpResponse;
import io.micronaut.security.oauth2.endpoint.nonce.persistence.NoncePersistence;
import jakarta.inject.Singleton;
import java.util.UUID;

/**
 * Generates a random UUID nonce.
 *
 * @author James Kleeh
 * @since 1.2.0
 */
@Requires(beans = NoncePersistence.class)
@Singleton
public class DefaultNonceFactory implements NonceFactory {

    private final NoncePersistence noncePersistence;

    /**
     * @param noncePersistence The nonce persistence mechanism
     */
    public DefaultNonceFactory(NoncePersistence noncePersistence) {
        this.noncePersistence = noncePersistence;
    }

    @NonNull
    @Override
    public String buildNonce(HttpRequest<?> request, MutableHttpResponse response) {
        String nonce = UUID.randomUUID().toString();
        noncePersistence.persistNonce(request, response, nonce);
        return nonce;
    }
}
